Index: chrome/browser/ui/webui/chrome_web_ui_factory.cc |
=================================================================== |
--- chrome/browser/ui/webui/chrome_web_ui_factory.cc (revision 88158) |
+++ chrome/browser/ui/webui/chrome_web_ui_factory.cc (working copy) |
@@ -100,7 +100,7 @@ |
// All platform builds of Chrome will need to have a cloud printing |
// dialog as backup. It's just that on Chrome OS, it's the only |
// print dialog. |
- if (url.host() == chrome::kChromeUICloudPrintResourcesHost) |
+ if (url.host() == chrome::kCloudPrintResourcesHost) |
return &NewWebUI<ExternalHtmlDialogUI>; |
// This will get called a lot to check all URLs, so do a quick check of other |
@@ -111,7 +111,7 @@ |
return NULL; |
if (url.host() == chrome::kChromeUISyncResourcesHost || |
- url.host() == chrome::kChromeUICloudPrintSetupHost) |
+ url.host() == chrome::kCloudPrintSetupHost) |
return &NewWebUI<HtmlDialogUI>; |
// Special case the new tab page. In older versions of Chrome, the new tab |
@@ -122,9 +122,8 @@ |
url.SchemeIs(chrome::kChromeInternalScheme)) |
return &NewWebUI<NewTabUI>; |
- // Return a generic Web UI so chrome:chrome-urls can navigate to Web UI pages. |
- if (url.host() == chrome::kChromeUIAboutHost || |
- url.host() == chrome::kChromeUIChromeURLsHost) |
+ // Give about:about a generic Web UI so it can navigate to pages with Web UIs. |
+ if (url.spec() == chrome::kChromeUIAboutAboutURL) |
return &NewWebUI<ChromeWebUI>; |
// We must compare hosts only since some of the Web UIs append extra stuff |
@@ -255,11 +254,11 @@ |
// It's possible to load about:blank in a Web UI renderer. |
// See http://crbug.com/42547 |
url.spec() == chrome::kAboutBlankURL || |
- // Chrome URLs crash, kill, hang, and shorthang are allowed. |
- url == GURL(chrome::kChromeUICrashURL) || |
- url == GURL(chrome::kChromeUIKillURL) || |
- url == GURL(chrome::kChromeUIHangURL) || |
- url == GURL(chrome::kChromeUIShorthangURL); |
+ // about:crash, about:kill, about:hang, and about:shorthang are allowed. |
+ url.spec() == chrome::kAboutCrashURL || |
+ url.spec() == chrome::kAboutKillURL || |
+ url.spec() == chrome::kAboutHangURL || |
+ url.spec() == chrome::kAboutShorthangURL; |
} |
WebUI* ChromeWebUIFactory::CreateWebUIForURL( |
@@ -306,7 +305,7 @@ |
} |
RefCountedMemory* ChromeWebUIFactory::GetFaviconResourceBytes( |
- const GURL& page_url) const { |
+ const GURL& page_url) const { |
// The bookmark manager is a chrome extension, so we have to check for it |
// before we check for extension scheme. |
if (page_url.host() == extension_misc::kBookmarkManagerId) |